#[non_exhaustive]pub struct MigrateOptions<'a> {
pub schema: &'a str,
}Expand description
Where migrate creates Reliar’s schema and its bookkeeping table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.schema: &'a strThe schema to create (CREATE SCHEMA IF NOT EXISTS) and use for both the data tables
and the _migrations bookkeeping table. SHALL agree with
crate::PostgresOutboxSettings::schema — crate::PostgresOutboxStore::connect’s
startup verification fails otherwise, since outbox will not resolve where it expects.
Implementations
Sourceimpl<'a> MigrateOptions<'a>
impl<'a> MigrateOptions<'a>
Sourcepub const fn schema(self, schema: &'a str) -> Self
pub const fn schema(self, schema: &'a str) -> Self
Sets Self::schema. #[non_exhaustive] forbids struct-literal construction outside
this crate, so this is the only way to migrate into a non-default schema.